@@ -238,13 +238,18 @@ class ProjectKey(Model):
             self.secret_key = ProjectKey.generate_api_key()
         super(ProjectKey, self).save(*args, **kwargs)
 
-    def get_dsn(self, domain=None, secure=True):
+    def get_dsn(self, domain=None, secure=True, public=False):
         # TODO: change the DSN to use project slug once clients are compatible
+        if not public:
+            key = '%s:%s' % (self.public_key, self.secret_key)
+        else:
+            key = self.public_key
+
         urlparts = urlparse.urlparse(settings.URL_PREFIX)
-        return '%s://%s:%s@%s/%s' % (
+
+        return '%s://%s@%s/%s' % (
             urlparts.scheme,
-            self.public_key,
-            self.secret_key,
+            key,
             urlparts.netloc + urlparts.path,
             self.project_id,
         )
@@ -316,45 +321,6 @@ class PendingTeamMember(Model):
             logger.exception(e)
 
 
-class ProjectDomain(Model):
-    """
-    Currently unused. Planned for 'trusted domains' for JS apis.
-    """
-    project = models.ForeignKey(Project, related_name="domain_set")
-    domain = models.CharField(max_length=128)
-
-    objects = BaseManager()
-
-    class Meta:
-        unique_together = (('project', 'domain'),)
-
-    def __unicode__(self):
-        return u'project=%s, domain=%s' % (self.project_id, self.domain)
-
-    @classmethod
-    def test(cls, project, url, strict=False):
-        """
-        Tests whether the ``url`` is a trusted domain for the given project.
-        """
-        if not url:
-            return False
-        url = urlparse.urlsplit(url).hostname
-        if not url:
-            # If we fail to parse the referral url
-            return False
-        if url in ('127.0.0.1', 'localhost'):
-            return True
-        if url.endswith('.local'):
-            return True
-        url = url.split('.')
-        domains = ProjectDomain.objects.filter(project=project).values_list('domain', flat=True)
-        for d in domains:
-            d = d.split('.')
-            if url[-len(d):] == d:
-                return True
-        return False
-
-
 class View(Model):
     """
     A view ties directly to a view extension and simply
@@ -567,6 +533,19 @@ class Event(MessageBase):
         module = self.data['__sentry__'].get('module', 'ver')
         return module, self.data['__sentry__']['version']
 
+    def as_dict(self):
+        # We use a SortedDict to keep elements ordered for a potential JSON serializer
+        data = SortedDict()
+        data['id'] = self.event_id
+        data['checksum'] = self.checksum
+        data['project'] = self.project.slug
+        data['logger'] = self.logger
+        data['level'] = self.get_level_display()
+        data['culprit'] = self.culprit
+        for k, v in sorted(self.data.iteritems()):
+            data[k] = v
+        return data
+
 
 class GroupBookmark(Model):
     """
