@@ -7,19 +7,6 @@ function varToggle(link, id) {
     return false;
 }
 
-function getQueryParams()
-{
-    var vars = {}, hash;
-    var href = window.location.href;
-    var hashes = href.slice(href.indexOf('?') + 1, (href.indexOf('#') !== -1 ? href.indexOf('#') : href.length)).split('&');
-    for(var i = 0; i < hashes.length; i++)
-    {
-        hash = hashes[i].split('=');
-        vars[hash[0]] = hash[1];
-    }
-    return vars;
-}
-
 (function() {
   /**
    * @private
@@ -304,6 +291,18 @@ if (Sentry === undefined) {
       $el.toggle();
     };
 
+    Sentry.getQueryParams = function() {
+        var vars = {}, hash;
+        var href = window.location.href;
+        var hashes = href.slice(href.indexOf('?') + 1, (href.indexOf('#') !== -1 ? href.indexOf('#') : href.length)).split('&');
+        for(var i = 0; i < hashes.length; i++)
+        {
+            hash = hashes[i].split('=');
+            vars[hash[0]] = decodeURIComponent(hash[1]).replace(/\+/, ' ');
+        }
+        return vars;
+    };
+
     $(document).ready(function(){
         $('.filter-list').each(function(_, el){
             var $el = $(el);
@@ -530,7 +529,7 @@ if (Sentry === undefined) {
             setTimeout(Sentry.realtime.poll, 1000);
             return;
         }
-        data = getQueryParams();
+        data = Sentry.getQueryParams();
         data.view_id = Sentry.realtime.options.viewId || undefined;
         data.cursor = Sentry.realtime.cursor || undefined;
         $.ajax({
